@@ -40,9 +40,9 @@ extern "C" {
 # include <sys/mount.h>
 #endif
 
-#define LIBMOUNT_VERSION   "2.39.1"
+#define LIBMOUNT_VERSION   "2.40.1"
 #define LIBMOUNT_MAJOR_VERSION   2
-#define LIBMOUNT_MINOR_VERSION   39
+#define LIBMOUNT_MINOR_VERSION   40
 #define LIBMOUNT_PATCH_VERSION   1
 
 /**
@@ -89,6 +89,7 @@ struct libmnt_optmap
 #define MNT_PREFIX	(1 << 3) /* prefix used for some options (e.g. "x-foo") */
 #define MNT_NOHLPS	(1 << 4) /* don't add the option to mount.<type> helpers command line */
 #define MNT_NOFSTAB	(1 << 5) /* not expected in fstab */
+#define MNT_SUPERBLOCK	(1 << 6) /* MS_* for mount(2), otherwise requires fsconfig() */
 
 /**
  * libmnt_fs:
@@ -188,7 +189,8 @@ enum {
 /**
  * MNT_ERR_APPLYFLAGS:
  *
- * failed to apply MS_PROPAGATION flags
+ * failed to apply MS_PROPAGATION flags, and MOUNT_ATTR_* attributes for
+ * mount_setattr(2)
  */
 #define MNT_ERR_APPLYFLAGS   5005
 /**
@@ -442,6 +444,8 @@ extern const struct libmnt_optmap *mnt_get_builtin_optmap(int id);
 /* lock.c */
 extern struct libmnt_lock *mnt_new_lock(const char *datafile, pid_t id)
 			__ul_attribute__((warn_unused_result));
+extern void mnt_ref_lock(struct libmnt_lock *ml);
+extern void mnt_unref_lock(struct libmnt_lock *ml);
 extern void mnt_free_lock(struct libmnt_lock *ml);
 
 extern void mnt_unlock_file(struct libmnt_lock *ml);
@@ -695,6 +699,8 @@ extern int mnt_monitor_enable_kernel(struct libmnt_monitor *mn, int enable);
 extern int mnt_monitor_enable_userspace(struct libmnt_monitor *mn,
 				int enable, const char *filename);
 
+extern int mnt_monitor_veil_kernel(struct libmnt_monitor *mn, int enable);
+
 extern int mnt_monitor_get_fd(struct libmnt_monitor *mn);
 extern int mnt_monitor_close_fd(struct libmnt_monitor *mn);
 extern int mnt_monitor_wait(struct libmnt_monitor *mn, int timeout);
